v.1.0.11/2019-07-31
    兼容了python2和python3
    修复了set_bucket_acl和set_bucket_logging的bug
v.1.0.10/2018-05-22
    修复分块上传listPart的bug
v.1.0.9/2018-04-18
    支持本地加密功能
v.1.0.8/2018-03-27
    增加Copy接口
v.1.0.7/2018-03-05
    发布至pypi
v.1.0.6/2017-11-13
    修复List接口偶尔会出现403的Bug
v.1.0.5/2017-07-17
    优化上传时异常处理
v1.0.4/2017-05-24
    支持自定义域名访问
v1.0.3/2017-04-11
    Bug Fix & 文档优化
v1.0.2/2016-10-19
    List Objects接口指定delimiter时,支持列出Prefix内容
v1.0.1/2016-03-02
    删除默认Host设置
    增加get_bucket_location接口
